# AbstractVision Playground

Calls an AbstractVision playground API (`/v1/vision/*`).

API Base URL

## Text → Image

Prompt a cinematic photo of a red fox in snow, 35mm, high detail Model Catalog
Negative prompt (optional)
Width
Height
Steps
Guidance scale
Seed (optional) Extra JSON (optional; forwarded to backend) {}
Download

## Image → Image (edits)

Select a model with edit capability to enable this panel.
Prompt make it watercolor
Uses the loaded model above.
Input image Mask image (optional) Negative prompt (optional)
Steps
Guidance scale
Seed (optional) Extra JSON (optional; forwarded to backend) {"strength": 0.75}
Download